==> cx88-1.2.1.tbz: include/cx88/cx88_common_ioctl.h <==
/*-
 * Copyright 2008 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */
 
#ifndef __CX88_COMMON_IOCTL_H__
#define __CX88_COMMON_IOCTL_H__

#define CX88_COMMON_MAX_I2C_DEVICES  8
#define CX88_COMMON_MAX_DRIVER_NAME 32

typedef struct
{
   uint8_t in_addr; /* Address of I2C device */
   
   /* I2C bus frequency for device to use */
   #define CX88_I2C_SPEED_100KHZ   0 /* 100 and 400KHz are supported by all CX2388x variants */
   #define CX88_I2C_SPEED_400KHZ   1
   #define CX23885_I2C_SPEED_2MHZ  2 /* 2MHz is only supported by CX23885/7 */
   uint8_t in_speed;
   
   /* Specifies the driver to use for this device */
   char in_driver[CX88_COMMON_MAX_DRIVER_NAME];
   
   /* Returns instance number of driver */
   int out_instance;
   
} cx88_i2c_device_config;

typedef struct
{
   #define CX23880_I2C_BUSES       1
   #define CX23885_I2C_BUSES       3
   /* I2C bus number (0-2 for CX23885/7, 0 for CX23880/1/2/3) */
   uint8_t in_bus_number;
   
   /* Device configuration for the bus */
   cx88_i2c_device_config devices[CX88_COMMON_MAX_I2C_DEVICES];
   
   /* Number of occupied slots in the above array */
   uint8_t in_num_i2c_devices;
} cx88_common_i2c_config;

/* GPIO pin control */
typedef struct
{
   uint32_t in_write_mask; /* Select bits in inout_gpio to be written */
   uint32_t in_read_mask; /* Select bits in inout_gpio to be read (any bits selected for writing will be written first) */
   uint32_t inout_gpio; /* GPIO bits (inout_gpio[23:0] -> GPIO pins [23:0] */
} cx88_common_gpio;

typedef struct
{
   #define CX23885_GPIO_CONTROL    0
   #define CX23885_GPIO_OUT_EN     1
   #define CX23885_GPIO_READ       2
   #define CX23885_GPIO_WRITE      3
   uint8_t in_action;
   
   uint32_t inout_value;
} cx23885_common_gpio;

#define CX88_COMMON_CARD_ID        _IOR('C', 0, uint32_t)
#define CX88_COMMON_I2C_CONFIG     _IOWR('C', 1, cx88_common_i2c_config)
#define CX88_COMMON_GPIO           _IOWR('C', 2, cx88_common_gpio)
#define CX88_COMMON_PERIPH_RESET   _IOW('C', 3, uint32_t)
#define CX23885_COMMON_GPIO        _IOWR('C', 4, cx23885_common_gpio)
#define CX23885_COMMON_BRIDGE      _IOR('C', 5, char[CX88_COMMON_MAX_DRIVER_NAME])

#define CX23885_STREAM_NONE        0
#define CX23885_STREAM_MPEG1       (1 << 0)
#define CX23885_STREAM_MPEG2       (1 << 1)
#define CX23885_COMMON_SET_STREAMS _IOW('C', 6, uint32_t)
#define CX23885_COMMON_GET_STREAMS _IOR('C', 7, uint32_t)

#endif

==> cx88-1.2.2.tbz: include/cx88/cx88_common_ioctl.h <==
/*-
 * Copyright 2008 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */
 
#ifndef __CX88_COMMON_IOCTL_H__
#define __CX88_COMMON_IOCTL_H__

#define CX88_COMMON_MAX_I2C_DEVICES  8
#define CX88_COMMON_MAX_DRIVER_NAME 32

typedef struct
{
   uint8_t in_addr; /* Address of I2C device */
   
   /* I2C bus frequency for device to use */
   #define CX88_I2C_SPEED_100KHZ   0 /* 100 and 400KHz are supported by all CX2388x variants */
   #define CX88_I2C_SPEED_400KHZ   1
   #define CX23885_I2C_SPEED_2MHZ  2 /* 2MHz is only supported by CX23885/7 */
   uint8_t in_speed;
   
   /* Specifies the driver to use for this device */
   char in_driver[CX88_COMMON_MAX_DRIVER_NAME];
   
   /* Returns instance number of driver */
   int out_instance;
   
} cx88_i2c_device_config;

typedef struct
{
   #define CX23880_I2C_BUSES       1
   #define CX23885_I2C_BUSES       3
   /* I2C bus number (0-2 for CX23885/7, 0 for CX23880/1/2/3) */
   uint8_t in_bus_number;
   
   /* Device configuration for the bus */
   cx88_i2c_device_config devices[CX88_COMMON_MAX_I2C_DEVICES];
   
   /* Number of occupied slots in the above array */
   uint8_t in_num_i2c_devices;
} cx88_common_i2c_config;

/* GPIO pin control */
typedef struct
{
   uint32_t in_write_mask; /* Select bits in inout_gpio to be written */
   uint32_t in_read_mask; /* Select bits in inout_gpio to be read (any bits selected for writing will be written first) */
   uint32_t inout_gpio; /* GPIO bits (inout_gpio[23:0] -> GPIO pins [23:0] */
} cx88_common_gpio;

#define CX88_COMMON_CARD_ID        _IOR('C', 0, uint32_t)
#define CX88_COMMON_I2C_CONFIG     _IOWR('C', 1, cx88_common_i2c_config)
#define CX88_COMMON_GPIO           _IOWR('C', 2, cx88_common_gpio)
#define CX88_COMMON_PERIPH_RESET   _IOW('C', 3, uint32_t)
#define CX23885_COMMON_MC_GPIO     _IOWR('C', 4, cx88_common_gpio)
#define CX23885_COMMON_BRIDGE      _IOR('C', 5, char[CX88_COMMON_MAX_DRIVER_NAME])

#define CX23885_STREAM_NONE        0
#define CX23885_STREAM_MPEG1       (1 << 0)
#define CX23885_STREAM_MPEG2       (1 << 1)
#define CX23885_COMMON_SET_STREAMS _IOW('C', 6, uint32_t)
#define CX23885_COMMON_GET_STREAMS _IOR('C', 7, uint32_t)

#endif
